@@ -22,7 +22,7 @@ for which a new license (GPL+exception) is in place.
 #include "scconfig.h"
 #include "gsutil.h"
 #include "util.h"
-
+#include "upgradechecker.h"
 #include "langmgr.h"
 
 extern QPixmap loadIcon(QString nam);
@@ -49,14 +49,14 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 	tabLayout1->setSpacing( 6 );
 	tabLayout1->setMargin( 15 );
 	pixmapLabel1 = new QLabel( tab, "PixmapLabel1" );
-	pixmapLabel1->setPixmap(loadIcon("scribus_logo.jpg"));
+	pixmapLabel1->setPixmap(loadIcon("scribus_logo.png"));
 	pixmapLabel1->setAlignment(Qt::AlignCenter);
 	tabLayout1->addWidget( pixmapLabel1 );
 	buildID = new QLabel( tab, "BB" );
 	buildID->setAlignment(Qt::AlignCenter);
-	QString BUILD_DAY = "9";
-	QString BUILD_MONTH = "Nov";
-	QString BUILD_YEAR = "2006";
+	QString BUILD_DAY = "25";
+	QString BUILD_MONTH = CommonStrings::february;
+	QString BUILD_YEAR = "2007";
 	QString BUILD_TIME = "";
 	QString BUILD_TZ = "";
 	QString BUILD_NAME = "";
@@ -140,7 +140,7 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 	tabLayout = new QHBoxLayout( tab_2 );
 	tabLayout->setSpacing( 6 );
 	tabLayout->setMargin( 10 );
-	textView1 = new QTextView( tab_2, "TextView1" );
+	textView1 = new TextBrowser( tab_2, "TextView1" );
 	textView1->setText(QString::fromUtf8("<table><tr><td><b>" + tr("Development Team:").utf8() + "</b></td><td> </td></tr>" +
 											"<tr><td>Franz Schmid</td><td>Franz.Schmid@altmuehlnet.de</td></tr>" +
 											"<tr><td>Peter Linnell</td><td>mrdocs@scribus.info</td></tr>" + 
@@ -151,6 +151,7 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 											"<tr><td>Craig Ringer</td><td>craig@postnewspapers.com.au</td></tr>" +
 											"<tr><td>Andreas Vox</td><td>avox@arcor.de</td></tr>" +
 											"<tr><td>Jean Ghali</td><td>jghali@libertysurf.fr</td></tr>" +
+											"<tr><td>Oleksandr Moskalenko</td><td>malex@tagancha.org</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 
 											"<tr><td><b>" + tr("Contributions from:").utf8()  + "</b></td><td></td></tr>" +
@@ -160,7 +161,6 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 											"<tr><td>Frank Everdij</td><td>f.everdij@citg.tudelft.nl</td></tr>" +
 											"<tr><td>S. Hakim Hamdani</td><td>hakimoto@eroteme.org</td></tr>" +
 											"<tr><td>Maciej Hański</td><td>m.hanski@gmx.at</td></tr>" +
-											"<tr><td>Oleksandr Moskalenko</td><td>malex@tagancha.org</td></tr>" +
 											"<tr><td>Marti Maria</td><td></td></tr>" +
 											"<tr><td>Alexandre Prokoudine</td><td>alexandre.prokoudine@gmail.com</td></tr>"
 											"<tr><td>Alessandro Rimoldi</td><td>http://ideale.ch/contact</td></tr>" +
@@ -169,12 +169,17 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 											"<tr><td>Jean-Jacques Sarton</td><td>jj.sarton@t-online.de</td></tr>" +
 											"<tr><td>Christian Töpp</td><td>mr-ct@gmx.de</td></tr>" +
 											"<tr><td>Eirik Øverby</td><td>ltning@anduin.net</td></tr>" +
+											"<tr><td>Kevin Young</td><td>k.young@youngscomputing.com</td></tr>" +
 											"<tr><td></td><td></td></tr>" +
 
 											"<tr><td><b>" + tr("Mac OS&#174; X Aqua Port:").utf8()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Andreas Vox</td><td>avox@arcor.de</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 
+											"<tr><td><b>" + tr("OS/2&#174;/eComStation&#8482; Port:").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td>Paul Smedley</td><td>paul@smedley.info</td></tr>" +
+											"<tr><td> </td><td> </td></tr>" +
+
 											"<tr><td><b>" + tr("Windows&#174; Port:").utf8()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Jean Ghali</td><td>jghali@libertysurf.fr</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
@@ -196,14 +201,13 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 											"<tr><td>Andreas Nilsson</td><td>nisses.mail@home.se</td></tr>" +
 											"<tr><td>Jakub Steiner</td><td>jimmac@ximian.com</td></tr>"  + 
 											"<tr><td> </td><td> </td></tr>" + "</table>"));
-	textView1->setTextFormat( QTextView::RichText );
 	tabLayout->addWidget( textView1 );
 	tabWidget2->insertTab( tab_2, tr( "A&uthors" ) );
 	tab_3 = new QWidget( tabWidget2, "tab_3" );
 	tabLayout_2 = new QHBoxLayout( tab_3 );
 	tabLayout_2->setSpacing( 6 );
 	tabLayout_2->setMargin( 10 );
-	textView2 = new QTextView( tab_3, "TextView1_2" );
+	textView2 = new TextBrowser( tab_3, "TextView1_2" );
 	LanguageManager langmgr;
 	langmgr.init(false);
 	textView2->setText(QString::fromUtf8( "<table><tr><td><b><i>" + tr("Official Translations and Translators:").utf8() + "</i></b></td><td></td></tr>" +
@@ -226,6 +230,8 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 											"<tr><td>Morten Langlo</td><td>mlanglo@mail.dk</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"<tr><td><b>" + langmgr.getLangFromAbbrev("nl").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td>Foppe Benedictus</td><td>foppe.benedictus@gmail.coml</td></tr>" +
+											"<tr><td>Erik Collou</td><td>collou@gmx.net</td></tr>" +
 											"<tr><td>Wilbert Berendsen</td><td>wbsoft@xs4all.nl</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"<tr><td><b>" + langmgr.getLangFromAbbrev("en_AU").utf8()  + "</b></td><td></td></tr>" +
@@ -274,6 +280,7 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 											"<tr><td>Kitae Kim</td><td>neeum@yahoo.com</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"<tr><td><b>" + langmgr.getLangFromAbbrev("nb").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td>Axel Bojer</td><td>axelb@skolelinux.no</td></tr>" +
 											"<tr><td>Klaus Ade Johnstad</td><td>klaus@inout.no</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"<tr><td><b>" + langmgr.getLangFromAbbrev("pl").utf8()  + "</b></td><td> </td></tr>" +
@@ -296,6 +303,7 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 											"<tr><td>Boštjan Špetič</td><td>igzebedze@kiberpipa.org</td></tr>" +
 											"<tr><td>Peter Čuhalev</td><td>skatey@slocartoon.net</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
+											"<tr><td>Martin Srebotnjak</td><td>miles@filmsi.net</td></tr>" +
 											"<tr><td><b>" + langmgr.getLangFromAbbrev("es_ES").utf8()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Josep Febrer</td><td>josep@linuxmail.org</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
@@ -343,7 +351,6 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 											"<tr><td>Aivaras Kirejevas</td><td>kiras@mail.lt</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"<tr><td><b>" + langmgr.getLangFromAbbrev("nb").utf8()  + "</b></td><td></td></tr>" +
-											"<tr><td>Axel Bojer</td><td>axelb@skolelinux.no</td></tr>" +
 											"<tr><td>Johannes Wilm</td><td>j@indymedia.no</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"<tr><td><b>" + langmgr.getLangFromAbbrev("tr").utf8()  + "</b></td><td> </td></tr>" +
@@ -353,13 +360,12 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 											"<tr><td>Sergiy Kudryk</td><td>kudryk@yahoo.com</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"</table>"));
-	textView2->setTextFormat( QTextView::RichText );
 	tabLayout_2->addWidget( textView2 );
 	tabWidget2->insertTab( tab_3, tr( "&Translations" ) );
 
 	// online tab (03/04/2004 petr vanek)
 	tab_4 = new QWidget( tabWidget2, "tab_4" );
-	textView4 = new QTextView( tab_4, "TextView4" );
+	textView4 = new TextBrowser( tab_4, "TextView4" );
 	textView4->setText(QString::fromUtf8(
 		"<table><tr><td><b>" + tr("Homepage").utf8() + "</b></td><td></td></tr>" +
 		"<tr><td colspan=\"2\"><p><a href=\"http://www.scribus.net\">http://www.scribus.net</a></p></td></tr>" +
@@ -372,12 +378,26 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 		"<tr><td><b>" + tr("Mailing List").utf8() + "</b></td><td></td></tr>" +
 		"<tr><td colspan=\"2\"><p><a href=\"http://nashi.altmuehlnet.de/mailman/listinfo/scribus\">http://nashi.altmuehlnet.de/mailman/listinfo/scribus</a></p></td></tr>" +
 		"</table>"));
-	textView4->setTextFormat( QTextView::RichText );
 	tabLayout_4 = new QHBoxLayout( tab_4 );
 	tabLayout_4->setSpacing( 6 );
 	tabLayout_4->setMargin( 10 );
 	tabLayout_4->addWidget( textView4 );
 	tabWidget2->insertTab( tab_4, tr( "&Online" ) );
+
+	// Update tab
+/*
+	tab_5 = new QWidget( tabWidget2, "tab_5" );
+	tabWidget2->insertTab( tab_5, tr( "&Updates" ) );
+	updateLayout = new QVBoxLayout( tab_5 );
+	updateLayout->setSpacing( 6 );
+	updateLayout->setMargin( 10 );
+	checkForUpdateButton = new QPushButton( tr( "Check for &Updates" ), tab_5, "checkForUpdateButton" );
+	textView5 = new TextBrowser( tab_5, "TextView5" );
+	updateLayout->addWidget( checkForUpdateButton );
+	updateLayout->addWidget( textView5 );
+*/
+
+
 	aboutLayout->addWidget( tabWidget2 );
 	layout2 = new QHBoxLayout;
 	layout2->setSpacing( 6 );
@@ -394,6 +414,16 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 //tooltips
 
 	QToolTip::add( buildID, "<qt>" + tr( "This panel shows the version, build date and compiled in library support in Scribus. The C-C-T-F equates to C=littlecms C=CUPS T=TIFF support F=Fontconfig support. Last Letter is the renderer C=cairo or A=libart Missing library support is indicated by a *. This also indicates the version of Ghostscript which Scribus has detected." ) + "</qt>" );
+//	QToolTip::add( checkForUpdateButton, "<qt>" + tr( "Check for updates to Scribus. No data from your machine will be transferred off it." ) + "</qt>" );
 	// signals and slots connections
 	connect( okButton, SIGNAL( clicked() ), this, SLOT( accept() ) );
+//	connect( checkForUpdateButton, SIGNAL( clicked() ), this, SLOT( runUpdateCheck() ) );
 }
+
+void About::runUpdateCheck()
+{
+	UpgradeCheckerGUI uc(textView5);
+	bool error=uc.fetch();
+	uc.show(error);
+}
+
