@@ -9,6 +9,7 @@ for which a new license (GPL+exception) is in place.
 #include <qvariant.h>
 #include <qfontmetrics.h>
 #include <qpixmap.h>
+#include <qbitmap.h>
 #include <cstdlib>
 
 #include "commonstrings.h"
@@ -54,7 +55,7 @@ void ColorSmallPixmapItem::paint( QPainter *p )
 	int itemHeight = height( listBox() );
     int yPos;
 
-	QColor rgb = color.getRawRGBColor();
+	QColor rgb = color.getDisplayColor();
 	smallPix.fill(rgb);
 	QPainter painter(&smallPix);
 	painter.setBrush(Qt::NoBrush);
@@ -96,7 +97,7 @@ void ColorWidePixmapItem::paint( QPainter *p )
 	int itemHeight = height( listBox() );
     int yPos;
 
-	QColor rgb = color.getRawRGBColor();
+	QColor rgb = color.getDisplayColor();
 	widePix.fill(rgb);
 
 	QRect rect;
@@ -149,7 +150,7 @@ void ColorFancyPixmapItem::paint( QPainter *p )
 	int itemHeight = height( listBox() );
     int yPos;
 
-	QColor rgb = color.getRawRGBColor();
+	QColor rgb = color.getDisplayColor();
 	smallPix.fill(rgb);
 	QPainter painter(&smallPix);
 	painter.setBrush(Qt::NoBrush);
@@ -158,7 +159,7 @@ void ColorFancyPixmapItem::paint( QPainter *p )
 	painter.drawRect(0, 0, 15, 15);
 	painter.end();
 
-	cellPix.fill(Qt::white);
+	cellPix.fill(Qt::color0);
 	paintAlert(smallPix, cellPix, 0, 0);
 	color.checkGamut();
 	if (color.isOutOfGamut())
@@ -168,9 +169,21 @@ void ColorFancyPixmapItem::paint( QPainter *p )
 	else
 		paintAlert(rgbIcon, cellPix, 30, 0);
 	if (color.isSpotColor())
-		paintAlert(spotIcon, cellPix, 46, 2);
+		paintAlert(spotIcon, cellPix, 46, 0);
 	if (color.isRegistrationColor())
 		paintAlert(regIcon, cellPix, 45, 0);
+	if (cellPix.mask() && ((!color.isSpotColor() && !color.isRegistrationColor()) || !color.isOutOfGamut()))
+	{
+		QPainter alpha; // transparency handling
+		alpha.begin(cellPix.mask());
+		alpha.setBrush(Qt::color0);
+		alpha.setPen(Qt::color0);
+		if (!color.isSpotColor() && !color.isRegistrationColor())
+			alpha.drawRect(45, 0, 15, 15);
+		if (!color.isOutOfGamut())
+			alpha.drawRect(15, 0, 15, 15);
+		alpha.end();
+	}
 
 	QRect rect;
 	rect.setCoords(3, 0, 60, 15);
@@ -697,11 +710,8 @@ void ColorManager::delUnused()
 		}
 	}
 	EditColors = UsedC;
-	if (EditColors.count() == 0)
-	{
-		EditColors.insert("White", ScColor(0, 0, 0, 0));
-		EditColors.insert("Black", ScColor(0, 0, 0, 255));
-	}
+	EditColors.insert("White", ScColor(0, 0, 0, 0));
+	EditColors.insert("Black", ScColor(0, 0, 0, 255));
 	updateCList();
 }
 
@@ -780,16 +790,19 @@ void ColorManager::delFarbe()
 	DelColor *dia = new DelColor(this, EditColors, sFarbe, HaveDoc);
 	if (dia->exec())
 	{
+		QString replacementColor(dia->getReplacementColor());
+		if (replacementColor == CommonStrings::NoneColor)
+			replacementColor = CommonStrings::None;
 		if (replaceMap.values().contains(sFarbe))
 		{
 			QMap<QString,QString>::Iterator it;
 			for (it = replaceMap.begin(); it != replaceMap.end(); ++it)
 			{
 				if (it.data() == sFarbe)
-					it.data() = dia->getReplacementColor();
+					it.data() = replacementColor;
 			}
 		}
-		replaceMap.insert(sFarbe, dia->getReplacementColor());
+		replaceMap.insert(sFarbe, replacementColor);
 		EditColors.remove(sFarbe);
 		updateCList();
 	}
@@ -804,23 +817,35 @@ void ColorManager::delFarbe()
 void ColorManager::selFarbe(QListBoxItem *c)
 {
 	sFarbe = c->text();
-	EditF->setEnabled(true);
+	bool enableEdit = (sFarbe != "Black" && sFarbe != "White");
+	bool enableDel  = (sFarbe != "Black" && sFarbe != "White") && (EditColors.count() > 1);
+	EditF->setEnabled(enableEdit);
 	DupF->setEnabled(true);
-	DelF->setEnabled(EditColors.count() == 1 ? false : true);
+	DelF->setEnabled(enableDel);
 }
 
 void ColorManager::selEditFarbe(QListBoxItem *c)
 {
 	sFarbe = c->text();
-	EditF->setEnabled(true);
+	bool enableEdit = (sFarbe != "Black" && sFarbe != "White");
+	bool enableDel  = (sFarbe != "Black" && sFarbe != "White") && (EditColors.count() > 1);
+	EditF->setEnabled(enableEdit);
 	DupF->setEnabled(true);
-	DelF->setEnabled(EditColors.count() == 1 ? false : true);
-	editFarbe();
+	DelF->setEnabled(enableDel);
+	if(enableEdit)
+		editFarbe();
 }
 
 void ColorManager::updateCList()
 {
-	colorListBox->updateBox(EditColors, ColorListBox::fancyPixmap);
+	ColorList::Iterator it;
+	colorListBox->clear();
+	for (it = EditColors.begin(); it != EditColors.end(); ++it)
+	{
+		if (it.key() == CommonStrings::None || it.key() == CommonStrings::NoneColor)
+			continue;
+		colorListBox->insertItem( new ColorFancyPixmapItem(it.data(), it.key()) );
+	}
 	DelF->setEnabled(EditColors.count() == 1 ? false : true);
 	if (colorListBox->currentItem() == -1)
 	{
