@@ -851,7 +851,10 @@ void PageItem_TextFrame::DrawObj_Item(ScPainter *p, QRect e, double sc)
 								}
 								else
 								{
-									CurY += m_Doc->docParagraphStyles[hl->cab].LineSpa;
+									if (m_Doc->docParagraphStyles[hl->cab].BaseAdj)
+										CurY += m_Doc->docParagraphStyles[hl->cab].FontSize / 10.0;
+									else
+										CurY += m_Doc->docParagraphStyles[hl->cab].LineSpa;
 									CurX = ColBound.x();
 								}
 								if (m_Doc->docParagraphStyles[hl->cab].BaseAdj)
@@ -1939,7 +1942,9 @@ void PageItem_TextFrame::DrawObj_Item(ScPainter *p, QRect e, double sc)
 			pf2.end();
 			p->restore();
 			break;
-			NoRoom: pf2.end();
+			
+NoRoom: 
+			pf2.end();
 			if (NextBox != 0)
 			{
 				nrc2 = itemText.count();
@@ -2109,6 +2114,8 @@ void PageItem_TextFrame::clearContents()
 		}
 		nextItem->itemText.clear();
 		nextItem->CPos = 0;
+		nextItem->Dirty = true;
+		nextItem->Redrawn = false;
 		nextItem = nextItem->NextBox;
 	}
 }
@@ -3051,8 +3058,8 @@ void PageItem_TextFrame::drawColumnBorders(ScPainter *p)
 	p->setupPolygon(&PoLine);
 	p->setClipPath();
 #endif
-	double startpos=Xpos;
-	double cols=0;
+//	double startpos=Xpos;
+//	double cols=0;
 	double colWidth = columnWidth();
 	double colLeft=0;
 	int currCol=0;
