@@ -87,7 +87,7 @@ OODrawImportPlugin::~OODrawImportPlugin()
 
 void OODrawImportPlugin::languageChange()
 {
-	importAction->setMenuText(tr("Import &OpenOffice.org Draw..."));
+	importAction->setMenuText( tr("Import &OpenOffice.org Draw..."));
 	// (Re)register file formats
 	unregisterAll();
 	registerFormats();
@@ -184,12 +184,15 @@ bool OODrawImportPlugin::import(QString fileName, int flags)
 		UndoManager::instance()->commit();
 	else
 		UndoManager::instance()->setUndoEnabled(true);
+	if (dia.unsupported)
+		QMessageBox::warning(ScMW, CommonStrings::trWarning, tr("This file contains some unsupported features"), 1, 0, 0);
 	return importDone;
 }
 
 OODPlug::OODPlug()
 {
 	interactive = false;
+	unsupported = false;
 	Doku = NULL;
 }
 
@@ -654,11 +657,12 @@ QPtrList<PageItem> OODPlug::parseGroup(const QDomElement &e)
 		}
 		else if( STag == "draw:path" )
 		{
-			z = Doku->itemAdd(PageItem::Polygon, PageItem::Unspecified, BaseX, BaseY, 10, 10, lwidth, FillColor, StrokeColor, true);
+			FPointArray pArray;
+			PageItem::ItemType itype = parseSVG(b.attribute("svg:d"), &pArray) ? PageItem::PolyLine : PageItem::Polygon;
+			z = Doku->itemAdd(itype, PageItem::Unspecified, BaseX, BaseY, 10, 10, lwidth, FillColor, StrokeColor, true);
 			PageItem* ite = Doku->Items->at(z);
 			ite->PoLine.resize(0);
-			if (parseSVG( b.attribute( "svg:d" ), &ite->PoLine ))
-				ite->convertTo(PageItem::PolyLine);
+			ite->PoLine = pArray;
 			if (ite->PoLine.size() < 4)
 			{
 				Doku->m_Selection->addItem(ite);
@@ -701,6 +705,7 @@ QPtrList<PageItem> OODPlug::parseGroup(const QDomElement &e)
 		}
 		else
 		{
+			unsupported = true;
 			qDebug("Not supported yet: %s", STag.local8Bit().data());
 			continue;
 		}
@@ -727,15 +732,15 @@ QPtrList<PageItem> OODPlug::parseGroup(const QDomElement &e)
 					if (m_styleStack.attribute("fo:text-align") == "right")
 						AbsStyle = 2;
 				}
-				if( m_styleStack.hasAttribute("fo:font-family"))
+				if( m_styleStack.hasAttribute("fo:font-size"))
 				{
-					FontSize = m_styleStack.attribute("fo:font-size").remove( "pt" ).toInt();
+					FontSize = (int) (m_styleStack.attribute("fo:font-size").remove( "pt" ).toFloat() * 10);
 				}
 /* ToDo: Add reading of Textstyles here */
-				ite->setLineSpacing(FontSize + FontSize * 0.2);
+				ite->setLineSpacing((FontSize + FontSize * 0.2) / 10.0);
 				Serializer *ss = new Serializer("");
 				ss->Objekt = QString::fromUtf8(e.text())+QChar(10);
-				ss->GetText(ite, AbsStyle, Doku->toolSettings.defFont, FontSize*10, firstPa);
+				ss->GetText(ite, AbsStyle, Doku->toolSettings.defFont, FontSize, firstPa);
 				delete ss;
 				firstPa = true;
 				if (! ite->asPolyLine())
@@ -760,88 +765,97 @@ QPtrList<PageItem> OODPlug::parseGroup(const QDomElement &e)
 			if (HaveGradient)
 			{
 				ite->GrType = 0;
-				ite->fill_gradient = gradient;
-				if (GradientType == 1)
+				if (gradient.Stops() > 1)
 				{
-					bool flipped = false;
-					if ((GradientAngle == 0) || (GradientAngle == 180) || (GradientAngle == 90) || (GradientAngle == 270))
+					ite->fill_gradient = gradient;
+					if (GradientType == 1)
 					{
-						if ((GradientAngle == 0) || (GradientAngle == 180))
+						bool flipped = false;
+						if ((GradientAngle == 0) || (GradientAngle == 180) || (GradientAngle == 90) || (GradientAngle == 270))
 						{
-							ite->GrType = 2;
-							//ScMW->view->updateGradientVectors(ite);
-							ite->updateGradientVectors();
-						}
-						else if ((GradientAngle == 90) || (GradientAngle == 270))
-						{
-							ite->GrType = 1;
-							//ScMW->view->updateGradientVectors(ite);
-							ite->updateGradientVectors();
-						}
-					}
-					else
-					{
-						if ((GradientAngle > 90) && (GradientAngle < 270))
-							GradientAngle -= 180;
-						else if ((GradientAngle > 270) && (GradientAngle < 360))
-						{
-							GradientAngle = 360 - GradientAngle;
-							flipped = true;
-						}
-						double xpos;
-						xpos = (ite->width() / 2) * tan(GradientAngle* M_PI / 180.0) * (ite->height() / ite->width()) + (ite->width() / 2);
-						if ((xpos < 0) || (xpos > ite->width()))
-						{
-							xpos = (ite->height() / 2)- (ite->height() / 2) * tan(GradientAngle* M_PI / 180.0) * (ite->height() / ite->width());
-							if (flipped)
+							if ((GradientAngle == 0) || (GradientAngle == 180))
 							{
-								ite->GrEndX = ite->width();
-								ite->GrEndY = ite->height() - xpos;
-								ite->GrStartX = 0;
-								ite->GrStartY = xpos;
+								ite->GrType = 2;
+								//ScMW->view->updateGradientVectors(ite);
+								ite->updateGradientVectors();
 							}
-							else
+							else if ((GradientAngle == 90) || (GradientAngle == 270))
 							{
-								ite->GrEndY = xpos;
-								ite->GrEndX = ite->width();
-								ite->GrStartX = 0;
-								ite->GrStartY = ite->height() - xpos;
+								ite->GrType = 1;
+								//ScMW->view->updateGradientVectors(ite);
+								ite->updateGradientVectors();
 							}
 						}
 						else
 						{
-							ite->GrEndX = xpos;
-							ite->GrEndY = ite->height();
-							ite->GrStartX = ite->width() - xpos;
-							ite->GrStartY = 0;
+							if ((GradientAngle > 90) && (GradientAngle < 270))
+								GradientAngle -= 180;
+							else if ((GradientAngle > 270) && (GradientAngle < 360))
+							{
+								GradientAngle = 360 - GradientAngle;
+								flipped = true;
+							}
+							double xpos;
+							xpos = (ite->width() / 2) * tan(GradientAngle* M_PI / 180.0) * (ite->height() / ite->width()) + (ite->width() / 2);
+							if ((xpos < 0) || (xpos > ite->width()))
+							{
+								xpos = (ite->height() / 2)- (ite->height() / 2) * tan(GradientAngle* M_PI / 180.0) * (ite->height() / ite->width());
+								if (flipped)
+								{
+									ite->GrEndX = ite->width();
+									ite->GrEndY = ite->height() - xpos;
+									ite->GrStartX = 0;
+									ite->GrStartY = xpos;
+								}
+								else
+								{
+									ite->GrEndY = xpos;
+									ite->GrEndX = ite->width();
+									ite->GrStartX = 0;
+									ite->GrStartY = ite->height() - xpos;
+								}
+							}
+							else
+							{
+								ite->GrEndX = xpos;
+								ite->GrEndY = ite->height();
+								ite->GrStartX = ite->width() - xpos;
+								ite->GrStartY = 0;
+							}
+							if (flipped)
+							{
+								ite->GrEndX = ite->width() - xpos;
+								ite->GrEndY = ite->height();
+								ite->GrStartX = xpos;
+								ite->GrStartY = 0;
+							}
+							ite->GrType = 6;
 						}
-						if (flipped)
+					}
+					if (GradientType == 2)
+					{
+						ite->GrType = 7;
+						ite->GrStartX = ite->width() * xGoff;
+						ite->GrStartY = ite->height()* yGoff;
+						if (ite->width() >= ite->height())
 						{
-							ite->GrEndX = ite->width() - xpos;
-							ite->GrEndY = ite->height();
-							ite->GrStartX = xpos;
-							ite->GrStartY = 0;
+							ite->GrEndX = ite->width();
+							ite->GrEndY = ite->height() / 2.0;
 						}
-						ite->GrType = 6;
+						else
+						{
+							ite->GrEndX = ite->width() / 2.0;
+							ite->GrEndY = ite->height();
+						}
+						//ScMW->view->updateGradientVectors(ite);
+						ite->updateGradientVectors();
 					}
 				}
-				if (GradientType == 2)
+				else
 				{
-					ite->GrType = 7;
-					ite->GrStartX = ite->width() * xGoff;
-					ite->GrStartY = ite->height()* yGoff;
-					if (ite->width() >= ite->height())
-					{
-						ite->GrEndX = ite->width();
-						ite->GrEndY = ite->height() / 2.0;
-					}
-					else
-					{
-						ite->GrEndX = ite->width() / 2.0;
-						ite->GrEndY = ite->height();
-					}
-					//ScMW->view->updateGradientVectors(ite);
-					ite->updateGradientVectors();
+					QPtrVector<VColorStop> cstops = gradient.colorStops();
+					ite->setFillColor(cstops.at(0)->name);
+					ite->setFillShade(cstops.at(0)->shade);
 				}
 				HaveGradient = false;
 			}
@@ -1011,6 +1025,8 @@ QString OODPlug::parseColor( const QString &s )
 	{
 		ScColor tmp;
 		tmp.fromQColor(c);
+		tmp.setSpotColor(false);
+		tmp.setRegistrationColor(false);
 		Doku->PageColors.insert("FromOODraw"+c.name(), tmp);
 		ScMW->propertiesPalette->updateColorList();
 		ret = "FromOODraw"+c.name();
