@@ -124,7 +124,13 @@ bool SVGExportPlugin::run(QString filename)
 		openDia->setExtension("svg");
 		openDia->setZipExtension("svgz");
 		if (openDia->exec())
+		{
+#ifdef HAVE_LIBZ
+			if (openDia->SaveZip->isChecked())
+				openDia->handleCompress();
+#endif
 			fileName = openDia->selectedFile();
+		}
 		delete openDia;
 
 		if (!fileName.isEmpty())
@@ -434,10 +440,13 @@ void SVGExPlug::ProcessPage(Page *Seite, QDomDocument *docu, QDomElement *elem)
 							multiLine ml = ScMW->doc->MLineStyles[Item->NamedLStyle];
 							for (int it = ml.size()-1; it > -1; it--)
 							{
-								ob = docu->createElement("path");
-								ob.setAttribute("d", SetClipPath(Item)+"Z");
-								ob.setAttribute("style", GetMultiStroke(&ml[it], Item));
-								gr.appendChild(ob);
+								if ((ml[it].Color != CommonStrings::None) && (ml[it].Width != 0))
+								{
+									ob = docu->createElement("path");
+									ob.setAttribute("d", SetClipPath(Item)+"Z");
+									ob.setAttribute("style", GetMultiStroke(&ml[it], Item));
+									gr.appendChild(ob);
+								}
 							}
 						}
 					break;
@@ -488,10 +497,13 @@ void SVGExPlug::ProcessPage(Page *Seite, QDomDocument *docu, QDomElement *elem)
 							multiLine ml = ScMW->doc->MLineStyles[Item->NamedLStyle];
 							for (int it = ml.size()-1; it > -1; it--)
 							{
-								ob = docu->createElement("path");
-								ob.setAttribute("d", SetClipPath(Item)+"Z");
-								ob.setAttribute("style", "fill:none; "+GetMultiStroke(&ml[it], Item));
-								gr.appendChild(ob);
+								if ((ml[it].Color != CommonStrings::None) && (ml[it].Width != 0))
+								{
+									ob = docu->createElement("path");
+									ob.setAttribute("d", SetClipPath(Item)+"Z");
+									ob.setAttribute("style", "fill:none; "+GetMultiStroke(&ml[it], Item));
+									gr.appendChild(ob);
+								}
 							}
 						}
 					break;
@@ -506,10 +518,13 @@ void SVGExPlug::ProcessPage(Page *Seite, QDomDocument *docu, QDomElement *elem)
 							multiLine ml = ScMW->doc->MLineStyles[Item->NamedLStyle];
 							for (int it = ml.size()-1; it > -1; it--)
 							{
-								ob = docu->createElement("path");
-								ob.setAttribute("d", SetClipPath(Item));
-								ob.setAttribute("style", GetMultiStroke(&ml[it], Item));
-								gr.appendChild(ob);
+								if ((ml[it].Color != CommonStrings::None) && (ml[it].Width != 0))
+								{
+									ob = docu->createElement("path");
+									ob.setAttribute("d", SetClipPath(Item));
+									ob.setAttribute("style", GetMultiStroke(&ml[it], Item));
+									gr.appendChild(ob);
+								}
 							}
 						}
 					break;
@@ -553,10 +568,13 @@ void SVGExPlug::ProcessPage(Page *Seite, QDomDocument *docu, QDomElement *elem)
 							multiLine ml = ScMW->doc->MLineStyles[Item->NamedLStyle];
 							for (int it = ml.size()-1; it > -1; it--)
 							{
-								ob = docu->createElement("path");
-								ob.setAttribute("d", "M 0 0 L "+FToStr(Item->width())+" 0");
-								ob.setAttribute("style", GetMultiStroke(&ml[it], Item));
-								gr.appendChild(ob);
+								if ((ml[it].Color != CommonStrings::None) && (ml[it].Width != 0))
+								{
+									ob = docu->createElement("path");
+									ob.setAttribute("d", "M 0 0 L "+FToStr(Item->width())+" 0");
+									ob.setAttribute("style", GetMultiStroke(&ml[it], Item));
+									gr.appendChild(ob);
+								}
 							}
 						}
 					break;
@@ -574,10 +592,13 @@ void SVGExPlug::ProcessPage(Page *Seite, QDomDocument *docu, QDomElement *elem)
 								multiLine ml = ScMW->doc->MLineStyles[Item->NamedLStyle];
 								for (int it = ml.size()-1; it > -1; it--)
 								{
-									ob = docu->createElement("path");
-									ob.setAttribute("d", SetClipPath(Item));
-									ob.setAttribute("style", GetMultiStroke(&ml[it], Item));
-									gr.appendChild(ob);
+									if ((ml[it].Color != CommonStrings::None) && (ml[it].Width != 0))
+									{
+										ob = docu->createElement("path");
+										ob.setAttribute("d", SetClipPath(Item));
+										ob.setAttribute("style", GetMultiStroke(&ml[it], Item));
+										gr.appendChild(ob);
+									}
 								}
 							}
 						}
